\name{Args}
\alias{Args}
\title{
  Formatted Argument List of a Function
}
\description{
  Display function argument names and corresponding default values,
  formatted in two columns for easy reading.
}
\usage{
Args(name, sort.args=FALSE)
}
\arguments{
  \item{name}{a function or function name.}
  \item{sort.args}{whether arguments should be sorted.}
}
\value{
  A data frame with named rows and a single column called \code{value},
  containing the default value of each argument.
}
\author{Arni Magnusson \email{arnima@u.washington.edu}}
\seealso{
  \code{\link{args}},
  \code{\link{formals}},
  \code{\link{help}}.
}
\examples{
Args(glm)
Args(bxp)
Args(legend)
}
% Programming
\keyword{programming}
\keyword{utilities}
\keyword{documentation}

\eof
% $Id: aggregate.table.Rd,v 1.5 2003/11/17 22:09:00 warnes Exp $
%
% $Log: aggregate.table.Rd,v $
% Revision 1.5  2003/11/17 22:09:00  warnes
% Fix syntax error.
%
% Revision 1.4  2003/06/07 17:58:37  warnes
%
% - Fixed error in examples.  Had sqrt(var(x)/(n-1)) for the standard
%   error of the mean instead of sqrt(var(x)/n).
%
% Revision 1.3  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
%

\name{aggregate.table}
\alias{aggregate.table}
\title{Create 2-Way Table of Summary Statistics}
\description{
  Splits the data into subsets based on two factors, computes a summary
  statistic on each subset, and arranges the results in a 2-way table.
}
\usage{
aggregate.table(x, by1, by2, FUN=mean, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{ data to be summarized }
  \item{by1}{ first grouping factor.  }
  \item{by2}{ second grouping factor. }
  \item{FUN}{ a scalar function to compute the summary statistics which can
          be applied to all data subsets. Defaults to \code{mean}.}
  \item{\dots}{ Optional arguments for \code{FUN}. }
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  Returns a matrix with one element for each combination of \code{by1}
  and \code{by2}.
}
\author{ Gregory R. Warnes \email{gregory\_r\_warnes\@groton.pfizer.com}}

\seealso{ \code{\link{aggregate}}, \code{\link{tapply}},
          \code{\link{interleave}} }

\examples{
# Useful example:
#
# Create a 2-way table of means, standard errors, and # obs

g1 <- sample(letters[1:5], 1000, replace=TRUE)
g2 <- sample(LETTERS[1:3], 1000, replace=TRUE )
dat <- rnorm(1000)

stderr <- function(x) sqrt( var(x,na.rm=TRUE) / nobs(x) )

means   <- aggregate.table( dat, g1, g2, mean )
stderrs <- aggregate.table( dat, g1, g2, stderr )
ns      <- aggregate.table( dat, g1, g2, nobs )
blanks <- matrix( " ", nrow=5, ncol=3)

tab <- interleave( "Mean"=round(means,2),
                   "Std Err"=round(stderrs,2),
                   "N"=ns, " " = blanks, sep=" " )

print(tab, quote=FALSE)
}
\keyword{iteration}
\keyword{category}


\eof
% $Id: combine.Rd,v 1.2 2002/09/23 13:59:30 warnes Exp $
%
% $Log: combine.Rd,v $
% Revision 1.2  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
%

\name{combine}
\alias{combine}
\title{ Combine R Objects With a Column Labeling the Source}
\description{
     Take a sequence of vector, matrix or data frames and
     combine into rows of a common data frame with an additional column
     \code{source} indicating the source object.
}
\usage{
combine(..., names=NULL)
}
\arguments{
  \item{\dots}{vectors or matrices to combine.}
  \item{names}{character vector of names to use when creating source column.}
}
\details{
     If there are several matrix arguments, they must all have the same
     number of columns.  The number of columns in the result will be one
     larger than the number of columns in the component matrixes. If all
     of the arguments are vectors, these are treated as single column
     matrixes.  In this case, the column containing the combineinated
     vector data is labeled \code{data}.
     
     When the arguments consist of a mix of matrices and vectors the
     number of columns of the result is determined by the number
     of columns of the matrix arguments.  Vectors are considered row
     vectors and have their values recycled or subsetted (if necessary)
     to achieve this length.

     The \code{source} column is created as a factor with levels
     corresponding to the name of the object from which the each row was
     obtained.  When the \code{names} argument is ommitted, the name of
     each object is obtained from the specified argument name in the
     call (if present) or from the name of the object.  See below for
     examples.
}
% \value{
%   ~Describe the value returned
%   If it is a LIST, use
%   \item{comp1 }{Description of `comp1'}
%   \item{comp2 }{Description of `comp2'}
%   ...
% }
%\references{ ~put references to the literature/web site here ~ }
\author{Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com}}
%\note{ ~~further notes~~ }
\seealso{ \code{\link{rbind}}, \code{\link{merge}}}

\examples{

a  <-  matrix(rnorm(12),ncol=4,nrow=3)
b  <-  1:4
combine(a,b)

combine(x=a,b)
combine(x=a,y=b)
combine(a,b,names=c("one","two"))

c <- 1:6
combine(b,c)
}

\keyword{array}
\keyword{manip}


\eof
\name{elem}
\alias{elem}
\title{
  Display Information about Elements in a Given Object
}
\description{
  Display name, class, size, and dimensions of each element in a given
  object.
}
\usage{
elem(object, unit=c("KB","MB","bytes"), digits=0, dimensions=FALSE)
}
\arguments{
  \item{object}{object containing named elements, perhaps a model or
    data frame.}
  \item{unit}{required unit for displaying element size: "KB", "MB",
    "bytes", or first letter.}
  \item{digits}{number of decimals to display when rounding element
    size.}
  \item{dimensions}{whether element dimensions should be returned.}
}
\details{
  A verbose alternative to \code{names()}.
}
\value{
  A data frame with named rows and the following columns:
  \item{Class}{element class.}
  \item{KB}{element size \emph{(see notes)}.}
  \item{Dim}{element dimensions \emph{(optional)}.}
}
\note{
  The name of the element size column is the same as the unit used.

  Elements of class \code{classRepresentation},
  \code{ClassUnionRepresentation}, and \code{grob} do not have a defined
  size, so 0 bytes are assumed for those.
}
\author{Arni Magnusson \email{arnima@u.washington.edu}}
\seealso{

  \code{\link[base]{names}}, \code{\link[utils]{str}}, and
  \code{\link[base]{summary}} display different information about object
  elements.

  \code{\link{ll}} and \code{\link{env}} are related to \code{elem}.
}
\examples{
data(infert)
elem(infert)
model <- glm(case~spontaneous+induced, family=binomial, data=infert)
elem(model, dim=TRUE)
elem(model$family)
}
% Basics
\keyword{attribute}
\keyword{classes}
\keyword{list}
% Programming
\keyword{print}
\keyword{utilities}

\eof
\name{env}
\alias{env}
\title{
  Display Information about All Loaded Environments
}
\description{
  Display name, number of objects, and size of all loaded environments.
}
\usage{
env(unit = c("KB", "MB", "bytes"), digits = 0)
}
\arguments{
  \item{unit}{required unit for displaying environment size: "KB", "MB",
    "bytes", or first letter.}
  \item{digits}{number of decimals to display when rounding environment
    size.}
}
\details{
  A verbose alternative to \code{search()}.
}
\value{
  A data frame with the following columns:
  \item{Environment}{environment name.}
  \item{Objects}{number of objects in environment.}
  \item{KB}{environment size \emph{(see notes)}.}
}
\note{
  The name of the environment size column is the same as the unit used.

  Objects of class \code{classRepresentation},
  \code{ClassUnionRepresentation}, and \code{grob} do not have a defined
  size, so 0 bytes are assumed for those.
}
\author{Arni Magnusson \email{arnima@u.washington.edu}}
\seealso{
  \code{\link{search}} displays environment names.

  \code{\link{ll}} and \code{\link{elem}} are related to \code{env}.
}
\examples{
\dontrun{
env()
}
}
% Basics
\keyword{data}
% Programming
\keyword{environment}
\keyword{utilities}

\eof
% $Id: interleave.Rd,v 1.4 2003/06/07 17:58:37 warnes Exp $
%
% $Log: interleave.Rd,v $
% Revision 1.4  2003/06/07 17:58:37  warnes
%
% - Fixed error in examples.  Had sqrt(var(x)/(n-1)) for the standard
%   error of the mean instead of sqrt(var(x)/n).
%
% Revision 1.3  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
% Revision 1.2  2002/04/09 00:51:32  warneg
%
% Checkin for version 0.5.3
%
% Revision 1.1  2002/02/20 21:41:54  warneg
% Initial checkin.
%
%


\name{interleave}
\alias{interleave}
\title{ Interleave Rows of Data Frames or Matrices }
\description{
  Interleave rows of data frames or Matrices.
}
\usage{
interleave(..., append.source=TRUE, sep=": ")
}
\arguments{
  \item{\dots}{ objects to be interleaved }
  \item{append.source}{Boolean Flag.  When \code{TRUE} (the default) the
    argument name will be appended to the row names to show the source of
    each row. }
  \item{sep}{Separator between the original row name and the object name.}
}
\details{
  This function creates a new matrix or data frame from its arguments.
  
  The new object will have all of the rows from the source objects
  interleaved. IE, it will contain row 1 of object 1, followed by row 1
  of object 2, .. row 1 of object 'n', row 2 of object 1, row 2 of
  object 2, ... row 2 of object 'n' ...
}
\value{
  Matrix containing the interleaved rows of the function arguments.
  }
\author{ Gregory R. Warnes \email{gregory\_r\_warnes\@groton.pfizer.com}
  }
\seealso{ \code{\link{cbind}}, \code{\link{rbind}}, \code{\link{combine}} }

\examples{

# Simple example
a <- matrix(1:10,ncol=2,byrow=TRUE)
b <- matrix(letters[1:10],ncol=2,byrow=TRUE)
c <- matrix(LETTERS[1:10],ncol=2,byrow=TRUE)
interleave(a,b,c)

# Useful example:
#
# Create a 2-way table of means, standard errors, and # obs

g1 <- sample(letters[1:5], 1000, replace=TRUE)
g2 <- sample(LETTERS[1:3], 1000, replace=TRUE )
dat <- rnorm(1000)

stderr <- function(x) sqrt( var(x,na.rm=TRUE) / nobs(x) )

means   <- aggregate.table( dat, g1, g2, mean )
stderrs <- aggregate.table( dat, g1, g2, stderr )
ns      <- aggregate.table( dat, g1, g2, nobs )
blanks <- matrix( " ", nrow=5, ncol=3)

tab <- interleave( "Mean"=round(means,2),
                   "Std Err"=round(stderrs,2),
                   "N"=ns, " " = blanks, sep=" " )

print(tab, quote=FALSE)

}
\keyword{category}
\keyword{array}


\eof
\name{is.what}
\alias{is.what}
\title{
  Run Multiple is.* Tests on a Given Object
}
\description{
  Run multiple \code{is.*} tests on a given object, such as
  \code{is.numeric()}, \code{is.list()}, ...
}
\usage{
is.what(object, verbose = FALSE)
}
\arguments{
  \item{object}{any R object.}
  \item{verbose}{whether negative tests should be included in output.}
}
\value{
  A character vector containing positive tests, or when \code{verbose}
  is \code{TRUE}, a data frame showing all test results.
}
\author{Arni Magnusson \email{arnima@u.washington.edu}, inspired by
  \code{demo(is.things)}.}
\seealso{
  \code{\link{is.na}} and \code{\link{is.numeric}} are commonly used
  tests.
}
\examples{
is.what(pi)
is.what(NA, verbose=TRUE)
is.what(lm(1~1))
}
% Basics
\keyword{classes}
\keyword{NA}
% Programming
\keyword{programming}
\keyword{error}
\keyword{utilities}

\eof
\name{keep}
\alias{keep}
\title{
  Remove All Objects, Except Those Specified
}
\description{
  Remove all objects from the default workspace, except those specified.
}
\usage{
keep(..., list = character(0), sure = FALSE)
}
\arguments{
  \item{...}{objects to be kept, specified one by one, quoted or
    unquoted.}
  \item{list}{character vector of object names to be kept.}
  \item{sure}{whether to perform the removal, otherwise return names of
    objects that would have been removed.}
}
\details{
  Convenient interface to \code{rm()} when removing most objects from
  the default workspace.

  Implemented with a few safety caps: objects whose name starts with a
  period \sQuote{\code{.}} are not removed, and \code{sure=TRUE} is
  required to perform the removal.
}
\value{
  A character vector containing object names, or \code{NULL} when
  \code{sure} is \code{TRUE}.
}
\author{Arni Magnusson \email{arnima@u.washington.edu}}
\seealso{
  \code{\link{rm}}.
}
\examples{
data(women, cars)
keep(cars)
## To remove all objects except cars, run:
## keep(cars, sure=TRUE)
}
% Programming
\keyword{data}
\keyword{environment}
\keyword{utilities}

\eof
\name{ll}
\alias{ll}
\alias{ll.default}
\alias{ll.data.frame}
\alias{ll.list}
\title{
  Display Information about Objects in a Given Environment
}
\description{
  Display name, class, size, and dimensions of each object in a given
  environment.
}
\usage{
ll(pos, ...)
\method{ll}{default}(pos=1, unit=c("KB","MB","bytes"), digits=0,
        dimensions=FALSE,function.dim="", ...)
\method{ll}{data.frame}(pos, ...)
\method{ll}{list}(pos, ...)

}
\arguments{
  \item{pos}{environment position number, environment name, list, or
    data frame.}
  \item{unit}{required unit for displaying object size: "KB", "MB",
    "bytes", or first letter.}
  \item{digits}{number of decimals to display when rounding object
    size.}
  \item{dimensions}{whether object dimensions should be returned.}
  \item{function.dim}{value to report as the dimension of function objects.}
  \item{...}{passed to \code{ls()}.}
}
\details{
  A verbose alternative to \code{ls()}.
}
\value{
  A data frame with named rows and the following columns:
  \item{Class}{object class.}
  \item{KB}{object size \emph{(see notes)}.}
  \item{Dim}{object dimensions \emph{(optional)}.}
}
\note{
  The name of the object size column is the same as the unit used.

  Objects of class \code{classRepresentation},
  \code{ClassUnionRepresentation}, and \code{grob} do not have a defined
  size, so 0 bytes are assumed for those.
}

\author{Arni Magnusson \email{arnima@u.washington.edu}.  Data frame and
  list methods contributed by Jim Rogers
  \email{james\_a\_rogers@groton.pfizer.com}.}

\seealso{
  \code{\link{ls}} displays names of objects in a given environment.

  \code{\link{elem}} and \code{\link{env}} are related to \code{ll}.
}
\examples{
ll()
ll(all=TRUE)
ll("package:base")
ll("package:base")[ll("package:base")$Class!="function",]

data(iris)
ll(iris)
}
% Basics
\keyword{data}
\keyword{attribute}
\keyword{classes}
% Programming
\keyword{environment}
\keyword{utilities}

\eof
\name{matchcols}
\alias{matchcols}
\title{Select columns names matching certain critera}
\description{
  This function allows easy selection of the column names of an object
  using a set of inclusion and exclusion critera.
}
\usage{
matchcols(object, with, without, method=c("and","or"), ...)
}
\arguments{
  \item{object}{Matrix or dataframe}
  \item{with, without}{Vector of regular expression patterns}
  \item{method}{One of "and" or "or"}
  \item{\dots}{Optional arguments to \code{grep}}
}
\value{
  Vector of column names which match all (\code{method="and"}) or any
  (\code{method="or"}) of the patterns specified in \code{with}, but
  none of the patterns specified in \code{without}.
}

\author{Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com}}
\seealso{ \code{\link[base]{grep}} }
\examples{

# create a matrix with a lot of named columns
x <- matrix( ncol=30, nrow=5 )
colnames(x) <- c("AffyID","Overall Group Means: Control",
                     "Overall Group Means: Moderate",
                     "Overall Group Means: Marked",
                     "Overall Group Means: Severe",
                     "Overall Group StdDev: Control",
                     "Overall Group StdDev: Moderate",
                     "Overall Group StdDev: Marked",
                     "Overall Group StdDev: Severe",
                     "Overall Group CV: Control",
                     "Overall Group CV: Moderate",
                     "Overall Group CV: Marked",
                     "Overall Group CV: Severe",
                     "Overall Model P-value",
                     "Overall Model: (Intercept): Estimate",
                     "Overall Model: Moderate: Estimate",
                     "Overall Model: Marked: Estimate",
                     "Overall Model: Severe: Estimate",
                     "Overall Model: (Intercept): Std. Error",
                     "Overall Model: Moderate: Std. Error",
                     "Overall Model: Marked: Std. Error",
                     "Overall Model: Severe: Std. Error",
                     "Overall Model: (Intercept): t value",
                     "Overall Model: Moderate: t value",
                     "Overall Model: Marked: t value",
                     "Overall Model: Severe: t value",
                     "Overall Model: (Intercept): Pr(>|t|)",
                     "Overall Model: Moderate: Pr(>|t|)",
                     "Overall Model: Marked: Pr(>|t|)",
                     "Overall Model: Severe: Pr(>|t|)")

# Get the columns which give estimates or p-values
# only for marked and severe groups
matchcols(x, with=c("Pr", "Std. Error"),
             without=c("Intercept","Moderate"),
             method="or"
          )

# Get just the column which give the p-value for the intercept
matchcols(x, with=c("Intercept", "Pr") )
                     
}
\keyword{manip}

\eof
% $Id: nobs.Rd,v 1.5 2002/09/23 13:59:30 warnes Exp $
%
% $Log: nobs.Rd,v $
% Revision 1.5  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
% Revision 1.4  2002/03/26 19:29:15  warneg
%
% Updated to add ... parameter to function calls.
%
% Revision 1.3  2002/02/20 21:31:08  warneg
%
% Noted that specialized methods exist.
%
% Revision 1.2  2002/02/20 21:29:34  warneg
%
% Incorrectly had contents of nobs.R here instead of help text.  Corrected.
%
%

\name{nobs}
\alias{nobs}
\alias{nobs.default}
\alias{nobs.data.frame}
\alias{nobs.lm}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{ Compute the Number of Non-missing Observations }
\description{
 Compute the number of non-missing observations.  Special methods exist for
 data frames, and lm objects.
}
\usage{
nobs(x, ...)
\method{nobs}{default}(x, ...)
\method{nobs}{data.frame}(x, ...)
\method{nobs}{lm}(x, ...)
}
\arguments{
  \item{x}{ Target Object }
  \item{\dots}{ Optional parameters (currently ignored)}
}
\details{

  In the simplest case, this is really just wrapper code for
  \code{sum(!is.na(x))}.
  
}
\value{
  A single numeric value or a vector of values (for data.frames) giving
  the number of non-missing values.
}
\author{ Gregory R. Warnes \email{gregory\_r\_warnes\@groton.pfizer.com}  }

\seealso{ \code{\link{is.na}}, \code{\link{length}} }

\examples{

x <- c(1,2,3,5,NA,6,7,1,NA )
length(x)
nobs(x)

df <- data.frame(x=rnorm(100), y=rnorm(100))
df[1,1] <- NA
df[1,2] <- NA
df[2,1] <- NA

nobs(df)
}
\keyword{attribute}

\eof
\name{read.xls}
\alias{read.xls}
\title{Read Excel files}
\description{Reads a Microsoft Excel file into a data frame}
\usage{
read.xls(xls, sheet=1, verbose=FALSE, ...)
}
\arguments{
  \item{xls}{name of the Microsoft Excel file}
  \item{sheet}{number of sheet within the Excel file from which data are
    to be read}
  \item{verbose}{logical flag indicating whether details should be
    printed as the file is processed.}
  \item{...}{additional arguments to read.table. The defaults of
    read.csv are used.}
}
\value{
  a data frame
}
\details{
  This function works translating the named Microsoft Excel file into a
  temporary .csv file, using Greg Warnes' xls2csv Perl script (installed
  as part of the gregmisc package).

  Note that, in the conversion to csv, strings will be quoted. This is a
  problem if you are trying to use the \code{comment.char} option of
  \code{read.table} since the first character of all lines (including
  comment lines) will be "\"" after conversion.
}
\references{http://www.analytics.washington.edu/statcomp/downloads/xls2csv}
\note{ A working version of Perl must be present in the executable
	search path for \code{read.xls} to work properly.}
\seealso{ \code{\link[base]{read.csv}} }
\examples{

   # iris.xls is included in the gregmisc package for use as an example
   xlsfile <- file.path(.path.package('gdata'),'xls','iris.xls')
   xlsfile

   iris <- read.xls(xlsfile)
   head(iris)  # look at the top few rows
}
\author{Jim Rogers \email{james\_a\_rogers@groton.pfizer.com}, modified
  and extended by Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com}.
}
\keyword{file}

\eof
% $Id: rename.vars.Rd,v 1.7 2004/04/01 20:23:15 warnes Exp $
%
% $Log: rename.vars.Rd,v $
% Revision 1.7  2004/04/01 20:23:15  warnes
% Add function remove.vars().
%
% Revision 1.6  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
%

\name{rename.vars}
\alias{rename.vars}
\alias{remove.vars}
\title{Remove or rename variables in a dataframe }
\description{
  Remove or rename a variables in a data frame.
}
\usage{
rename.vars(data, from="", to="", info=TRUE)
remove.vars(data, names="", info=TRUE)
}
\arguments{
  \item{data}{ dataframe to be modified.  }
  \item{from}{ character vector containing the current name of each
    variable to be renamed.}
  \item{to}{ character vector containing the new name of each variable
    to be renamed.}
  \item{names}{ character vector containing the names of variables to be
    removed.}
  \item{info}{ boolean value indicating whether to print details of the
    removal/renaming.  Defaults to TRUE.}
}
%\details{
%  ~~ If necessary, more details than the __description__  above ~~
%}
\value{
  The updated data frame with variables listed in \code{from} renamed to
  the corresponding element of \code{to}.
}
\author{Code by Don MacQueen \email{macq\@llnl.gov}.
  Documentation by Gregory R. Warnes
  \email{gregory\_r\_warnes\@groton.pfizer.com} }
\seealso{ \code{\link{names}},
  \code{\link{colnames}},
  \code{\link{data.frame}}
}

\examples{
data <- data.frame(x=1:10,y=1:10,z=1:10)
names(data)
data <- rename.vars(data, c("x","y","z"), c("first","second","third"))
names(data)

data <- remove.vars(data, "second")
names(data)
}
\keyword{ manip  }


\eof
% $Id: reorder.Rd,v 1.10 2004/09/03 17:27:44 warneg Exp $


\name{reorder.factor}
\alias{reorder.factor}
\title{Reorder the Levels of a Factor}
\description{
  Reorder the levels of a factor
}
\usage{
\method{reorder}{factor}(x,
                         order,
                         X,
                         FUN,
                         sort=mixedsort,
                         make.ordered = is.ordered(x),
                         ... )
}
\arguments{
  \item{x}{factor.}
  \item{order}{A vector of indexes or a vector of label names giving the
    order of the new factor levels.}
  \item{X}{auxillary data vector}
  \item{FUN}{function to be applied to subsets of \code{X} determined by
    \code{x}, to determine factor order.}
  \item{sort}{function to use to sort the factor level names}
  \item{make.ordered}{logical value indicating whether the returned
    object should be an \code{'ordered'} factor.}
  \item{...}{Optional parameters to FUN.}
}
\details{
  This function changes the order of the levels of a factor.  It can do
  so via three different mechanisms, depending on whether \code{order},
  \code{X} \emph{and} \code{FUN}, or \code{sort} are provided.

  If \code{order} is provided:  For a numeric vector, the new factor level names
  are constructed by reordering the factor levels according to the
  numeric values. For vectors, \code{order} gives the list of new factor
  level names. In either case levels omitted from \code{order} will
  become missing values.

  If \code{X} \emph{and} \code{Fun} are provided: The data in \code{X}
  is grouped by the levels of \code{data} and \code{FUN} is applied.
  The groups are then sorted by this value, and the resulting order is
  used for the new factor level names.

  If \code{sort} is provided (as it is by default): The new
  factor level names are generated by applying the supplied function
  to the existing factor level names.  With \code{order="mixedsort"} the
  factor levels are sorted so that combined numeric and character
  strings are sorted in according to character rules on the character
  sections (including ignoring case), and be numeric rules for the
  numeric sections.  See \code{mixedsort} for details.

}
\value{
  A new factor with the levels ordered as specified.
}

\author{Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com}}

\seealso{ \code{\link{factor}}, \code{\link[stats]{reorder}} }

\examples{
   # Create a 4 level example factor
   trt <- factor( sample( c("PLACEBO","300 MG", "600 MG", "1200 MG"),
                  100, replace=TRUE ) )
   summary(trt)
   # Note that the levels are not in a meaningful order.


   # Change the order to something useful
   # default "mixedsort" ordering
   trt2 <- reorder(trt)
   summary(trt2)
   # using indexes:
   trt3 <- reorder(trt, c(4,2,3,1))
   summary(trt3)
   # using label names:
   trt4 <- reorder(trt, c("PLACEBO","300 MG", "600 MG", "1200 MG") )
   summary(trt4)
   # using frequency
   trt5 <- reorder(trt, X=as.numeric(trt), FUN=length)
   summary(trt5)


   # drop out the '300 MG' level
   trt6 <- reorder(trt, c("PLACEBO", "600 MG", "1200 MG") )
   summary(trt6)
}
\keyword{ manip }

\eof
\name{trim}
\alias{trim}
\title{Remove leading and trailing spaces from character strings}
\description{
 Remove leading and traling spaces from character strings
}
\usage{
trim(s)
}
\arguments{
  \item{s}{character string(s) to be processed}
}
\value{
  Elements of \code{s} with all leading and traling spaces removed.
}
\author{ Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com} }
\seealso{ \code{\link[base]{sub}}, \code{\link[base]{gsub}} }
\examples{
s <- "    this is an example string    "
trim(s)
}
\keyword{character}

\eof
