% $Id: combinations.Rd,v 1.8 2004/05/26 13:40:13 warnes Exp $
%
% $Log: combinations.Rd,v $
% Revision 1.8  2004/05/26 13:40:13  warnes
% Escape underscores in email addresses so Latex is happy.
%
% Revision 1.7  2004/03/26 22:21:15  warnes
% Uncomment and fix large 'n' example.
%
% Revision 1.6  2003/04/22 16:00:27  warnes
% - Fixed tpyo in example that allowed combinations(500,2) to run when
%   it should have been ignred for testing..
%
% Revision 1.5  2003/04/10 16:22:29  warnes
%
% - Added note about the need to increase options("expressions") to use
%   large values for 'n'.  Prompted by bug report from Huan Huang
%   <huan.huang@bnpparibas.com
%
% Revision 1.4  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
% Revision 1.3  2002/04/09 00:51:32  warneg
%
% Checkin for version 0.5.3
%
% Revision 1.2  2001/08/25 05:50:58  warneg
% Fixed a typo and a syntax error.
%
% Revision 1.1  2001/06/29 13:24:08  warneg
%
% Initial revision.
%

\name{combinations}
\alias{combinations}
\alias{permutations}
\title{Enumerate the Combinations or Permutations of the Elements of a Vector}
\description{
  \code{combinations} enumerates the possible combinations of a
  specified size from the elements of a vector.  \code{permutations}
  enumerates the possible permutations.
}
\usage{
combinations(n, r, v=1:n, set=TRUE, repeats.allowed=FALSE)
permutations(n, r, v=1:n, set=TRUE, repeats.allowed=FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{ Size of the source vector }
  \item{r}{ Size of the target vectors }
  \item{v}{ Source vector. Defaults to \code{1:n}}
  \item{set}{ Logical flag indicating whether duplicates should be
    removed from the source vector \code{v}. Defaults to \code{TRUE}.}
  \item{repeats.allowed}{ Logical flag indicating whether the
    constructed vectors nay include duplicated values.  Defaults to
    \code{FALSE}.  }
}
\details{
  Caution: The number of combinations and permutations increases rapidly
  with \code{n} and \code{r}!.

  To use values of \code{n} above about 45, you will need to increase
  R's recursion limit.  See the \code{expression} argument to the
  \code{options} command for details on how to do this.
}
\value{
  Returns a matrix where each row contains a vector of length \code{n}.
}
\references{Venables, Bill.  "Programmers Note", R-News, Vol 1/1,
  Jan. 2001. \url{http://cran.r-project.org/doc/Rnews} }
\author{ Original versions by Bill Venables
  \email{Bill.Venables@cmis.csiro.au}.  Extended to handle
  \code{repeats.allowed} by Gregory R. Warnes
  \email{Gregory\_R\_Warnes@groton.pfizer.com}.
  }
\seealso{ \code{\link[base]{choose}}, \code{\link[base]{options}} }
\examples{
combinations(3,2,letters[1:3])
combinations(3,2,letters[1:3],repeats=TRUE)

permutations(3,2,letters[1:3])
permutations(3,2,letters[1:3],repeats=TRUE)

# To use large 'n', you need to change the default recusion limit
options(expressions=1e5)
cmat <- combinations(300,2)
dim(cmat) # 44850 by 2 
}
\keyword{ manip }

\eof
\name{rdirichlet}
\alias{rdirichlet}
\alias{ddirichlet}
\title{Functions for the Dirichlet Distribution}
\description{
  Functions to compute the density of or generate random deviates from
  the Dirichlet distribution.
}
\usage{
rdirichlet(n, alpha)
ddirichlet(x, alpha)
}
\arguments{
  \item{x}{A vector containing a single random deviate or matrix
    containg one random deviate per row.} 
  \item{n}{Number of random vectors to generate. }
  \item{alpha}{Vector or (for \code{ddirichlet}) matrix containing shape
    parameters. }
}
\details{
  The Dirichlet distribution is the multidimensional generalization of
  the beta distribution.  It is the canonical Bayesian distribution for
  the parameter estimates of a multinomial distribution.
}
\value{
  \code{ddirichlet} returns a vector containing the Dirichlet density for the
  corresponding rows of \code{x}.

  \code{rdirichlet} returns a matrix with \code{n} rows, each containing
  a single Dirichlet random deviate.
}
\author{
  Code original posted by Ben Bolker to R-News on Fri Dec 15 2000. See
  \url{http://www.r-project.org/nocvs/mail/r-help/2000/3865.html}.  Ben 
  attributed the code to Ian Wilson \email{i.wilson@maths.abdn.ac.uk}.
  Subsequent modifications by Gregory R. Warnes
  \email{gregory\_r\_warnes@groton.pfizer.com}.
}
\seealso{ \code{\link{dbeta}}, \code{\link{rbeta}} }
\examples{

  x <- rdirichlet(20, c(1,1,1) )

  ddirichlet(x, c(1,1,1) )

}
\keyword{distribution}

\eof
\name{foldchange}
\alias{foldchange}
\alias{logratio2foldchange}
\alias{foldchange2logratio}
\title{Compute fold-change or convert between log-ratio and fold-change.}
\description{
  \code{foldchange} computes the fold change for two sets of values.
  \code{logratio2foldchange} converts values from log-ratios to fold
  changes.  \code{foldchange2logratio} does the reverse.
}
\usage{
foldchange(num,denom)
logratio2foldchange(logratio, base=2)
foldchange2logratio(foldchange, base=2)
}
\arguments{
  \item{num,denom}{vector/matrix of numeric values}
  \item{logratio}{vector/matrix of log-ratio values}
  \item{foldchange}{vector/matrix of fold-change values}
  \item{base}{Exponential base for the log-ratio.}
}
\details{
  Fold changes are commonly used in the biological sciences as a
  mechanism for comparing the relative size of two measurements.  They
  are computed as: \eqn{\frac{num}{denom}}{num/denom} if
  \eqn{num>denom}, and as \eqn{\frac{-denom}{num}}{-denom/num}
  otherwise.

  Fold-changes have the advantage of ease of interpretation and symmetry
  about \eqn{num=denom}, but suffer from a discontinuty between -1 and
  1, which can cause significant problems when performing data
  analysis.  Consequently statisticians prefer to use log-ratios.
}
\value{
  A vector or matrix of the same dimensions as the input containing the
  converted values.
}
\author{ Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com} }
\examples{

  a <- 1:21
  b <- 21:1

  f <- foldchange(a,b)

  cbind(a,b,f)

}
\keyword{math}

\eof
\name{invalid}
\alias{invalid}
\title{Test if a value is missing, empty, or contains only NA or NULL values}
\description{ 
  Test if a value is missing, empty, or contains only NA or NULL values.
}
\usage{
invalid(x)
}
\arguments{
  \item{x}{value to be tested}
}
%\details{
%}
\value{
  Logical value.
}
\author{Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com} }
\seealso{ \code{\link[base]{missing}}, \code{\link[base]{is.na}},
  \code{\link[base]{is.null}} }
\examples{

invalid(NA)
invalid()
invalid(c(NA,NA,NULL,NA))

invalid(list(a=1,b=NULL))

# example use in a function
myplot <- function(x,y) {
                if(invalid(y)) {
                        y <- x
                        x <- 1:length(y)
                }
                plot(x,y)
        }
myplot(1:10)
myplot(1:10,NA)
}
\keyword{programming}

\eof
% $Id: logit.Rd,v 1.2 2003/11/21 20:54:06 warnes Exp $

\name{logit}
\alias{logit}
\alias{inv.logit}
\title{Generalized logit and inverse logit function}
\description{
  Compute generalized logit and generalized inverse logit functions.
}
\usage{
logit(x, min = 0, max = 1)
inv.logit(x, min = 0, max = 1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{value(s) to be transformed}
  \item{min}{Lower end of logit interval}
  \item{max}{Upper end of logit interval}
}
\details{

  The generalized logit function takes values on [min, max] and
  transforms them to span [-Inf,Inf] it is defined as:

    \deqn{y = log(\frac{p}{(1-p)})}{y = log(p/(1-p))}

  where
    
    \deqn{p=\frac{(x-min)}{(max-min)}}{p=(x-min)/(max-min)}

  The generized inverse logit function provides the inverse
  transformation:
    
    \deqn{x = p' (max-min) + min}{x = p * (max-min) + min}

  where

    \deqn{p'=\frac{exp(y)}{(1+exp(y))}}{exp(y)/(1+exp(y))}


}
\value{
  Transformed value(s).
}
\author{ Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com} }
\seealso{ \code{\link[car]{logit}}, \code{\link[moc]{inv.glogit}} }
\examples{

  x <- seq(0,10, by=0.25)
  xt <- logit(x, min=0, max=10)
  cbind(x,xt)

  y <- inv.logit(xt, min=0, max=10)
  cbind(x,xt,y)  

}
\keyword{math}

\eof
\name{mixedsort}
\alias{mixedsort}
\alias{mixedorder}
\title{Order or Sort strings with embedded numbers so that the numbers
  are in the correct order}
\description{
  These functions sort or order character strings containing numbers so
  that the numbers are numerically sorted rather than sorted by
  character value.  I.e. "Asprin 50mg" will come before "Asprin 100mg".
  In addition, case of character strings is ignored so that "a", will
  come before "B" and "C".
}
\usage{
mixedsort(x)
}
\arguments{
  \item{x}{ Character vector to be sorted }
}
\details{
  I often have character vectors (e.g. factor labels) that contain
  both text and numeric data, such as compound and dose.  This function
  is useful for sorting these character vectors into a logical order.

  It does so by splitting each character vector into a sequence of
  character and numeric sections, and then sorting along these sections,
  with numbers being sorted by numeric value (e.g. "50" comes before
  "100"), followed by characters strings sorted by character
  value (e.g. "A" comes before "B").

  Empty strings are always sorted to the front of the list, and \code{NA}
  values to the end.
}
\value{
  \code{mixedorder} returns a vector giving the sort order of the input
  elements. \code{mixedsort} returns the sorted vector.
}
\author{ Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com} }
\seealso{ \code{\link[base]{sort}}, \code{\link[base]{order}} }
\examples{
# compound & dose labels
Treatment <- c("Control", "Asprin 10mg/day", "Asprin 50mg/day",
               "Asprin 100mg/day", "Acetomycin 100mg/day",
               "Acetomycin 1000mg/day")

# ordinary sort puts the dosages in the wrong order
sort(Treatment)

# but mixedsort does the 'right' thing
mixedsort(Treatment)

# Here is a more complex example
x <- rev(c("AA 0.50 ml", "AA 1.5 ml", "AA 500 ml", "AA 1500 ml",
           "EXP 1", "AA 1e3 ml", "A A A", "1 2 3 A", "NA", NA, "1e2",
           "", "-", "1A", "1 A", "100", "100A", "Inf"))

mixedorder(x)

mixedsort(x)
# notice that plain numbers, including 'Inf' show up before strings.

}
\keyword{univar}
\keyword{manip}



\eof
\name{odd}
\alias{odd}
\alias{even}
\title{Detect odd/even integers }
\description{
 detect odd/even integers
}
\usage{
odd(x)
even(x)
}
\arguments{
  \item{x}{ vector of integers }
}
\value{
  Vector of TRUE/FALSE values.
}
\author{ Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com}}
\seealso{ \code{\link[base]{round}} }
\examples{

odd(4)
even(4)

odd(1:10)
even(1:10)

}
\keyword{arith}

\eof
\name{permute}
\alias{permute}
\title{Randomly Permute the Elements of a Vector}
\description{
  Randomly Permute the elements of a vector
}
\usage{
permute(x)
}
\arguments{
  \item{x}{ Vector of items to be permuted }
}
\details{
  This is simply a wrapper function for \code{\link{sample}}.
}
\value{
  Vector with the original items reordered.
}
\author{ Gregory R. Warnes \email{gregory\_r\_warnes@groton.pfizer.com} }
\seealso{ \code{\link{sample}} }

\examples{
  x <- 1:10
  permute(x)
}
\keyword{distribution}

\eof
% $Id: quantcut.Rd,v 1.2 2002/09/23 13:59:30 warnes Exp $
%
% $Log: quantcut.Rd,v $
% Revision 1.2  2002/09/23 13:59:30  warnes
% - Modified all files to include CVS Id and Log tags.
%
% Revision 1.1  2002/03/26 14:49:10  warneg
%
% Initial Checkin
%
%

\name{quantcut}
\alias{quantcut}

\title{ Create a Factor Variable Using the Quantiles of a Continuous Variable}}
\description{
  Create a factor variable using the quantiles of a continous variable.
}
\usage{
quantcut(x, q=c(0, 1/4, 2/4, 3/4, 4/4), na.rm=TRUE, include.lowest=TRUE, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{ Continous variable. }
  \item{q}{ Vector of quantiles used for creating groups. Defaults to
    \code{c(0, 1/4, 2/4, 3/4, 4/4)}.  See \code{\link{quantile}} for details. }
  \item{na.rm}{ Boolean indicating whether missing values should be
    removed when computing quantiles.  Defaults to TRUE.}
  \item{include.lowest}{ Boolean indicating whether values exactly
    equal to the lowest specified quantile be included in the lowest
    group.  See \code{\link{cut}} for details. }
  \item{\dots}{ Optional arguments passed to \code{\link{cut}}. }
}
\details{
  This function is simply a uses \code{\link{quantile}} to obtaine the
  quantiles of \code{x}, then calls \code{\link{cut}} to create a factor
  variable using the quantiles for cut points.
}
\value{
  Factor variable with one level for each quantile interval given by \code{q}.
}

\author{Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com}}

\seealso{ \code{\link{cut}}, \code{\link{quantile}} }

\examples{

  x <- rnorm(1000)
  quants <- quantcut( x )
  table(quants)
}

\keyword{ manip  }


\eof
% $Id: running.Rd,v 1.11 2004/09/27 21:01:21 warneg Exp $

\name{running}
\alias{running}
\title{Apply a Function Over Adjacent Subsets of a Vector}
\description{Applies a function over subsets of the vector(s) formed by
  taking a fixed number of previous points.}
\usage{
running(X, Y=NULL, fun=mean, width=min(length(X), 20),
        allow.fewer=FALSE, pad=FALSE, align=c("right", "center","left"),
        simplify=TRUE, by, ...)
}
\arguments{
  \item{X}{ data vector }
  \item{Y}{ data vector (optional) }
  \item{fun}{ Function to apply. Default is \code{mean}}
  \item{width}{Integer giving the number of vector elements to include
    in the subsets.  Defaults to the lesser of the length of the data and
    20 elements.}
  \item{allow.fewer}{Boolean indicating whether the function should be
    computed for subsets with fewer than \code{width} points}
  \item{pad}{Boolean indicating whether the returned results should
    be 'padded' with NAs corresponding to sets with less than
    \code{width} elements.  This only applies when when
    \code{allow.fewer} is FALSE.}
  \item{align}{One of "right", "center", or "left".
    This controls the relative location of `short' subsets with less
    then \code{width} elements: "right" allows short subsets only at the
    beginning of the sequence so that all of the complete subsets are at
    the end of the sequence (i.e. `right aligned'), "left" allows short
    subsets only at the end of the data so that the complete subsets
    are `left aligned', and "center" allows short subsets at both ends
    of the data so that complete subsets are `centered'.
  }
  \item{simplify}{Boolean.  If FALSE the returned object will be a list
    containing one element per evaluation.  If TRUE, the returned
    object will be coerced into a vector (if the computation returns a
    scalar) or a matrix (if the computation returns multiple values).
    Defaults to FALSE.}
  \item{by}{Integer separation between groups. If \code{by=width} will
    give non-overlapping windows. Default is missing, in which case
    groups will start at each value in the X/Y range.}
  \item{\dots}{ parameters to be passed to \code{fun} }
}
\details{
  \code{running} applies the specified function to
  a sequential windows on \code{X} and (optionally) \code{Y}.  If
  \code{Y} is specified the function must be bivariate.
}
\value{
  List (if \code{simplify==TRUE}), vector, or matrix containg the
  results of applying the function \code{fun} to the
  subsets of \code{X} (\code{running}) or \code{X} and \code{Y}.

  Note that this function will create a vector or matrix even for
  objects which are not simplified by \code{sapply}.
}
\author{ Gregory R. Warnes \email{Gregory\_R\_Warnes@groton.pfizer.com},
         with contributions by Nintin Jain \email{nitin\_jain@groton.pfizer.com}.}
\seealso{ \code{\link[gplots]{wapply}} to apply a function over an x-y window
  centered at each x point, \code{\link[base]{sapply}},
  \code{\link[base]{lapply}} }

\examples{

# show effect of pad
running(1:20, width=5)
running(1:20, width=5, pad=TRUE)

# show effect of align
running(1:20, width=5, align="left", pad=TRUE)
running(1:20, width=5, align="center", pad=TRUE)
running(1:20, width=5, align="right", pad=TRUE)

# show effect of simplify
running(1:20, width=5, fun=function(x) x )  # matrix
running(1:20, width=5, fun=function(x) x, simplify=FALSE) # list

# show effect of by
running(1:20, width=5)       # normal
running(1:20, width=5, by=5) # non-overlapping
running(1:20, width=5, by=2) # starting every 2nd


# Use 'pad' to ensure correct length of vector, also show the effect
# of allow.fewer.
par(mfrow=c(2,1))
plot(1:20, running(1:20, width=5, allow.fewer=FALSE, pad=TRUE), type="b")
plot(1:20, running(1:20, width=5, allow.fewer=TRUE,  pad=TRUE), type="b")
par(mfrow=c(1,1))

# plot running mean and central 2 standard deviation range
# estimated by *last* 40 observations
dat <- rnorm(500, sd=1 + (1:500)/500 )
plot(dat)
sdfun <- function(x,sign=1) mean(x) + sign * sqrt(var(x))
lines(running(dat, width=51, pad=TRUE, fun=mean), col="blue")
lines(running(dat, width=51, pad=TRUE, fun=sdfun, sign=-1), col="red")
lines(running(dat, width=51, pad=TRUE, fun=sdfun, sign= 1), col="red")


# plot running correlation estimated by last 40 observations (red)
# against the true local correlation (blue)
sd.Y <- seq(0,1,length=500)

X <- rnorm(500, sd=1)
Y <- rnorm(500, sd=sd.Y)

plot(running(X,X+Y,width=20,fun=cor,pad=TRUE),col="red",type="s")

r <- 1 / sqrt(1 + sd.Y^2) # true cor of (X,X+Y)
lines(r,type="l",col="blue")
}
\keyword{misc}

\eof
